@@ -1,7 +1,7 @@
 package Chemistry::OpenSMILES;
 
 # ABSTRACT: OpenSMILES format reader and writer
-our $VERSION = '0.11.0'; # VERSION
+our $VERSION = '0.11.2'; # VERSION
 
 use strict;
 use warnings;
@@ -89,8 +89,10 @@ sub clean_chiral_centers($$)
                     is_chiral_planar( $atom )  ||
                     is_chiral_tetrahedral( $atom ) ||
                     is_chiral_trigonal_bipyramidal( $atom );
-        # Anomers must not loose chirality settings in any way
-        next if is_ring_atom( $moiety, $atom, scalar $moiety->edges );
+
+        # Find neighbours which constitute ring bonds with the atom in question
+        my @ring_neighbours = grep { is_ring_bond( $moiety, $atom, $_, scalar $moiety->edges ) }
+                                   $moiety->neighbours( $atom );
 
         my $hcount = exists $atom->{hcount} ? $atom->{hcount} : 0;
         my @neighbours = $moiety->neighbours( $atom );
@@ -121,6 +123,20 @@ sub clean_chiral_centers($$)
             next if scalar keys %colors == 4;
         }
 
+        # Special treatment for anomers
+        if( @ring_neighbours ) {
+            next unless is_chiral_tetrahedral( $atom );
+            next unless @ring_neighbours == 2;
+            next if $hcount == 1;
+            if( !$hcount ) {
+                my @non_ring_neighbours = grep { $_ != $ring_neighbours[0] &&
+                                                 $_ != $ring_neighbours[1] }
+                                               @neighbours;
+                next unless $color_sub->( $non_ring_neighbours[0] ) eq
+                            $color_sub->( $non_ring_neighbours[1] );
+            }
+        }
+
         delete $atom->{chirality};
         push @affected, $atom;
     }
